@@ -223,33 +223,33 @@ class Player(Base):
             if b_key in ('batting_rating', 'overall_rating'):
                 original_json['tragicness'] = max(0.01, original_json['tragicness'] - b_val)
                 original_json['patheticism'] = max(0.01, original_json['patheticism'] - b_val)
-                original_json['thwackability'] += b_val
-                original_json['divinity'] += b_val
-                original_json['moxie'] += b_val
-                original_json['musclitude'] += b_val
-                original_json['martyrdom'] += b_val
+                original_json['thwackability'] = max(0.01, original_json['thwackability'] + b_val)
+                original_json['divinity'] = max(0.01, original_json['divinity'] + b_val)
+                original_json['moxie'] = max(0.01, original_json['moxie'] + b_val)
+                original_json['musclitude'] = max(0.01, original_json['musclitude'] + b_val)
+                original_json['martyrdom'] = max(0.01, original_json['martyrdom'] + b_val)
             if b_key in ('pitching_rating', 'overall_rating'):
-                original_json['unthwackability'] += b_val
-                original_json['ruthlessness'] += b_val
-                original_json['overpowerment'] += b_val
-                original_json['shakespearianism'] += b_val
-                original_json['coldness'] += b_val
+                original_json['unthwackability'] = max(0.01, original_json['unthwackability'] + b_val)
+                original_json['ruthlessness'] = max(0.01, original_json['ruthlessness'] + b_val)
+                original_json['overpowerment'] = max(0.01, original_json['overpowerment'] + b_val)
+                original_json['shakespearianism'] = max(0.01, original_json['shakespearianism'] + b_val)
+                original_json['coldness'] = max(0.01, original_json['coldness'] + b_val)
             if b_key in ('baserunning_rating', 'overall_rating'):
-                original_json['laserlikeness'] += b_val
-                original_json['continuation'] += b_val
-                original_json['baseThirst'] += b_val
-                original_json['indulgence'] += b_val
-                original_json['groundFriction'] += b_val
+                original_json['laserlikeness'] = max(0.01, original_json['laserlikeness'] + b_val)
+                original_json['continuation'] = max(0.01, original_json['continuation'] + b_val)
+                original_json['baseThirst'] = max(0.01, original_json['baseThirst'] + b_val)
+                original_json['indulgence'] = max(0.01, original_json['indulgence'] + b_val)
+                original_json['groundFriction'] = max(0.01, original_json['groundFriction'] + b_val)
             if b_key in ('defense_rating', 'overall_rating'):
-                original_json['omniscience'] += b_val
-                original_json['tenaciousness'] += b_val
-                original_json['watchfulness'] += b_val
-                original_json['anticapitalism'] += b_val
-                original_json['chasiness'] += b_val
+                original_json['omniscience'] = max(0.01, original_json['omniscience'] + b_val)
+                original_json['tenaciousness'] = max(0.01, original_json['tenaciousness'] + b_val)
+                original_json['watchfulness'] = max(0.01, original_json['watchfulness'] + b_val)
+                original_json['anticapitalism'] = max(0.01, original_json['anticapitalism'] + b_val)
+                original_json['chasiness'] = max(0.01, original_json['chasiness'] + b_val)
             if b_key in ('tragicness', 'patheticism'):
-                original_json[b_key] = max(0, original_json[b_key] - b_val)
+                original_json[b_key] = max(0.01, original_json[b_key] - b_val)
             elif b_key in original_json:
-                original_json[b_key] += b_val
+                original_json[b_key] = max(0.01, original_json[b_key] + b_val)
 
         return Player(original_json)
 
@@ -543,6 +543,176 @@ class Game(Base):
     def weather(self, value):
         self._weather = value
 
+    @property
+    def home_team(self):
+        if self._home_team:
+            return self._home_team
+        self._home_team = Team.load(self._home_team_id)
+        return self._home_team
+
+    @home_team.setter
+    def home_team(self, value):
+        self._home_team = None
+        self._home_team_id = value
+
+    @property
+    def away_team(self):
+        if self._away_team:
+            return self._away_team
+        self._away_team = Team.load(self._away_team_id)
+        return self._away_team
+
+    @away_team.setter
+    def away_team(self, value):
+        self._away_team = None
+        self._away_team_id = value
+
+    @property
+    def home_pitcher(self):
+        if self._home_pitcher:
+            return self._home_pitcher
+        self._home_pitcher = Player.load_one(self._home_pitcher_id)
+        return self._home_pitcher
+
+    @home_pitcher.setter
+    def home_pitcher(self, value):
+        self._home_pitcher = None
+        self._home_pitcher_id = value
+
+    @property
+    def away_pitcher(self):
+        if self._away_pitcher:
+            return self._away_pitcher
+        self._away_pitcher = Player.load_one(self._away_pitcher_id)
+        return self._away_pitcher
+
+    @away_pitcher.setter
+    def away_pitcher(self, value):
+        self._away_pitcher = None
+        self._away_pitcher_id = value
+
+    @property
+    def home_batter(self):
+        if not self._home_batter_id:
+            return None
+        if self._home_batter:
+            return self._home_batter
+        self._home_batter = Player.load_one(self._home_batter_id)
+        return self._home_batter
+
+    @home_batter.setter
+    def home_batter(self, value):
+        self._home_batter = None
+        self._home_batter_id = value
+
+    @property
+    def away_batter(self):
+        if not self._away_batter_id:
+            return None
+        if self._away_batter:
+            return self._away_batter
+        self._away_batter = Player.load_one(self._away_batter_id)
+        return self._away_batter
+
+    @away_batter.setter
+    def away_batter(self, value):
+        self._away_batter = None
+        self._away_batter_id = value
+
+    @property
+    def at_bat_team(self):
+        if self.top_of_inning:
+            return self.away_team
+        else:
+            return self.home_team
+
+    @property
+    def at_bat_team_name(self):
+        if self.top_of_inning:
+            return self.away_team_name
+        else:
+            return self.home_team_name
+
+    @property
+    def at_bat_team_nickname(self):
+        if self.top_of_inning:
+            return self.away_team_nickname
+        else:
+            return self.home_team_nickname
+
+    @property
+    def pitching_team(self):
+        if self.top_of_inning:
+            return self.home_team
+        else:
+            return self.away_team
+
+    @property
+    def pitching_team_name(self):
+        if self.top_of_inning:
+            return self.home_team_name
+        else:
+            return self.away_team_name
+
+    @property
+    def pitching_team_nickname(self):
+        if self.top_of_inning:
+            return self.home_team_nickname
+        else:
+            return self.away_team_nickname
+
+    @property
+    def current_pitcher(self):
+        if self.top_of_inning:
+            return self.home_pitcher
+        else:
+            return self.away_pitcher
+
+    @property
+    def current_pitcher_name(self):
+        if self.top_of_inning:
+            return self.home_pitcher_name
+        else:
+            return self.away_pitcher_name
+
+    @property
+    def current_batter(self):
+        if self.top_of_inning:
+            return self.away_batter
+        else:
+            return self.home_batter
+
+    @property
+    def current_batter_name(self):
+        if self.top_of_inning:
+            return self.away_batter_name
+        else:
+            return self.home_batter_name
+
+    @property
+    def season(self):
+        return self._season
+
+    @season.setter
+    def season(self, value):
+        self._season = value + 1
+
+    @property
+    def day(self):
+        return self._day
+
+    @day.setter
+    def day(self, value):
+        self._day = value + 1
+
+    @property
+    def inning(self):
+        return self._inning
+
+    @inning.setter
+    def inning(self, value):
+        self._inning = value + 1
+
 
 class DecreeResult(Base):
 
